# remirepo spec file for php-symfony-psr-http-message-bridge, from:
#
# Fedora spec file for php-symfony-psr-http-message-bridge
#
# Copyright (c) 2015-2019 Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     symfony
%global github_name      psr-http-message-bridge
%global github_version   1.1.2
%global github_commit    a33352af16f78a5ff4f9d90811536abf210df12b

%global composer_vendor  symfony
%global composer_project psr-http-message-bridge

# "php": "^5.3.3 || ^7.0"
%global php_min_ver 5.3.3
# "psr/http-message": "^1.0"
%global psr_http_message_min_ver 1.0
%global psr_http_message_max_ver 2.0
# "symfony/http-foundation": "^2.3.42 || ^3.4 || ^4.0"
%global symfony_min_ver %{?el6:2.3.42}%{!?el6:2.7.1}
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
%global symfony_max_ver 5.0
%else
%global symfony_max_ver 4.0
%endif

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_vendor}-%{composer_project}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Symfony PSR HTTP message bridge

License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}
Source0:       %{url}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

BuildArch:     noarch
# Tests
%if %{with_tests}
BuildRequires: php-composer(phpunit/phpunit)
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(psr/http-message) >= %{psr_http_message_min_ver} with php-composer(psr/http-message) < %{psr_http_message_max_ver})
BuildRequires: (php-composer(symfony/http-foundation) >= %{symfony_min_ver} with php-composer(symfony/http-foundation) < %{symfony_max_ver})
%else
BuildRequires: php-composer(psr/http-message) <  %{psr_http_message_max_ver}
BuildRequires: php-composer(psr/http-message) >= %{psr_http_message_min_ver}
BuildRequires: php-composer(symfony/http-foundation) <  %{symfony_max_ver}
#BuildRequires: php-composer(symfony/http-foundation) >= %%{symfony_min_ver}
%endif
## phpcompatinfo (computed from version 1.1.2)
BuildRequires: php-date
BuildRequires: php-reflection
BuildRequires: php-spl
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-composer(psr/http-message) >= %{psr_http_message_min_ver} with php-composer(psr/http-message) < %{psr_http_message_max_ver})
Requires:      (php-composer(symfony/http-foundation) >= %{symfony_min_ver} with php-composer(symfony/http-foundation) < %{symfony_max_ver})
%else
Requires:      php-composer(psr/http-message) <  %{psr_http_message_max_ver}
Requires:      php-composer(psr/http-message) >= %{psr_http_message_min_ver}
Requires:      php-composer(symfony/http-foundation) <  %{symfony_max_ver}
#Requires:      php-composer(symfony/http-foundation) >= %%{symfony_min_ver}
%endif
# phpcompatinfo (computed from version 1.1.2)
Requires:      php-date
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
Provides integration for PSR7.

Autoloader: %{phpdir}/Symfony/Bridge/PsrHttpMessage/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Create autoloader
cat <<'AUTOLOAD' | tee autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Symfony\\Bridge\\PsrHttpMessage\\', __DIR__);

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Psr/Http/Message/autoload.php',
    array(
        '%{phpdir}/Symfony4/Component/HttpFoundation/autoload.php',
        '%{phpdir}/Symfony3/Component/HttpFoundation/autoload.php',
        '%{phpdir}/Symfony/Component/HttpFoundation/autoload.php',
    ),
));
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}/Symfony/Bridge/PsrHttpMessage
cp -rp *.php Factory Tests %{buildroot}%{phpdir}/Symfony/Bridge/PsrHttpMessage/


%check
%if %{with_tests}
: Create tests bootstrap
cat <<'BOOTSTRAP' | tee -a bootstrap.php
<?php
require_once '%{buildroot}%{phpdir}/Symfony/Bridge/PsrHttpMessage/autoload.php';
if (!class_exists('PHPUnit\\Framework\\TestCase')) {
    class_alias('PHPUnit_Framework_TestCase', 'PHPUnit\\Framework\\TestCase');
}
BOOTSTRAP

: Upstream tests
RETURN_CODE=0
PHPUNIT=$(which phpunit)
for PHP_EXEC in "" %{?rhel:php54 php55 php56 php70} php71 php72 php73 php74; do
    if [ -z "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC $PHPUNIT --verbose --bootstrap bootstrap.php \
            || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{phpdir}/Symfony/Bridge/PsrHttpMessage
%exclude %{phpdir}/Symfony/Bridge/PsrHttpMessage/Tests


%changelog
* Wed May 15 2019 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.1.2-1
- Update to 1.1.2
- Remove php-composer(zendframework/zend-diactoros) interoperability (no longer
  suggested in composer.json)

* Sun Apr 22 2018 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.2-2
- Fix el6 tests

* Sun Apr 22 2018 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.2-1
- Update to 1.0.2 (RHBZ #1528620)
- Add range version dependencies for Fedora >= 27 || RHEL >= 8
- Add composer.json to repo
- Remove tests' patch

* Thu Sep 21 2017 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.0-3
- Allow Symfony 3
- Modify tests
- Apply patch to fix test suite with !el6 and zendframework/zend-diactoros

* Sat Apr 15 2017 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.0.0-1
- Update to 1.0.0 (RHBZ #1370802)
- Add max versions to BuildRequires
- Switch autoloader to php-composer(fedora/autoloader)
- Test with SCLs if available

* Wed Aug  5 2015 Remi Collet <remi@remirepo.net> - 0.2-2
- backport for #remirepo

* Sun Aug 02 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.2-2
- Fixed dependency versions
- Added php-composer(zendframework/zend-diactoros) build dependency for tests
  (excluding el6)
- Autoloader update
- Fixed %%files

* Wed Jul 08 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.2-1
- Initial package
